==> imdb-movie-1.6.4.tgz: package/terminal-interface/terminal.js <==
const term = require( 'terminal-kit' ).terminal ;
const fs = require('fs');
const utils = require('../utils/utils');

const hereFolder = '.';
const cancel = 'cancel';
const rootDirectory =".";

function showFoldersMenu(callback) {
    let dir ;
    let items =fs.readdirSync('.');
    items.push(cancel);
    items.push(hereFolder);
    items.reverse();

    var options = {
        y: 1 ,	// the menu will be on the top of the terminal
        style: term.bold ,
        selectedStyle: term.bold.blue
    } ;

    term.clear() ;
    term.green('choose the directory of your movies, if you are in movie directory just press enter');

    term.gridMenu( items , options , function( error , response ) {
        term( '\n' ).eraseLineAfter.green(
            "#%s selected: %s (%s,%s)\n" ,
            response.selectedText
        ) ;
        term.clear();

        switch (response.selectedText) {
           case hereFolder:
               dir = rootDirectory;
               callback(dir)
                break;

            case cancel:
                process.exit() ;
                break;

            default:
                dir = rootDirectory +"/"+response.selectedText;
                callback(dir)
                break
        }
        // term.clear();
    } ) ;

}

function showOverWriteMenu(dir) {
    const overWrite = "overWrite exiting movies";
    const dontOverWrite = "don't over write";
    const items =[overWrite , dontOverWrite];

    var options = {
        y: 1 ,	// the menu will be on the top of the terminal
        style: term.bold ,
        selectedStyle: term.bold.blue
    } ;


    term.singleColumnMenu( items , options , function( error , response ) {
        term( '\n' ).eraseLineAfter.green(
            "#%s selected: %s (%s,%s)\n" +
            "directory of movie : "+dir +"\n\n",
            response.selectedText
        ) ;
        switch (response.selectedText) {
            case overWrite:
                utils.getDirectoryNameAndFetchMoviesItem(dir, true)
                break;

            case dontOverWrite:
                utils.getDirectoryNameAndFetchMoviesItem(dir, false)
                break;

            default:
                dir = rootDirectory +"/"+response.selectedText;
                break
        }

    } ) ;
}


module.exports ={
    showFoldersMenu,
    showOverWriteMenu
};

==> imdb-movie-1.7.10.tgz: package/terminal-interface/terminal.js <==
const term = require( 'terminal-kit' ).terminal ;
const fs = require('fs');
const utils = require('../utils/utils');

const hereFolder = '.';
const cancel = 'cancel';
const rootDirectory =".";

function showFoldersMenu(callback) {
    let dir ;
    let items =fs.readdirSync('.');
    items.push(cancel);
    items.push(hereFolder);
    items.reverse();

    var options = {
        y: 1 ,	// the menu will be on the top of the terminal
        style: term.bold ,
        selectedStyle: term.bold.blue
    } ;

    term.clear() ;
    term.green('choose the directory of your movies, if you are in movie directory just press enter');

    term.gridMenu( items , options , function( error , response ) {
        term( '\n' ).eraseLineAfter.green(
            "#%s selected: %s (%s,%s)\n" ,
            response.selectedText
        ) ;
        term.clear();

        switch (response.selectedText) {
           case hereFolder:
               dir = rootDirectory;
               callback(dir)
                break;

            case cancel:
                process.exit() ;
                break;

            default:
                dir = rootDirectory +"/"+response.selectedText;
                callback(dir)
                break
        }
        // term.clear();
    } ) ;

}

function showOverWriteMenu(dir) {
    const overWriteAll = "overWrite All movies data";
    const overWriteMoviewWithoutDirectorName = "overWrite movies without director name";
    const dontOverWrite = "don't over write";
    const items =[overWriteAll, overWriteMoviewWithoutDirectorName , dontOverWrite];

    var options = {
        y: 1 ,	// the menu will be on the top of the terminal
        style: term.bold ,
        selectedStyle: term.bold.blue
    } ;


    term.singleColumnMenu( items , options , function( error , response ) {
        term( '\n' ).eraseLineAfter.green(
            "#%s selected: %s (%s,%s)\n" +
            "directory of movie : "+dir +"\n\n",
            response.selectedText
        ) ;
        switch (response.selectedText) {
            case overWriteAll:
                utils.getDirectoryNameAndFetchMoviesItem(dir, true, true)
                break;

            case overWriteMoviewWithoutDirectorName:
                utils.getDirectoryNameAndFetchMoviesItem(dir, false, true)
                break;
            case dontOverWrite:
                utils.getDirectoryNameAndFetchMoviesItem(dir, false, false)
                break;

            default:
                dir = rootDirectory +"/"+response.selectedText;
                break
        }

    } ) ;
}


module.exports ={
    showFoldersMenu,
    showOverWriteMenu
};
